# @push.rocks/webstore
high performance storage in the browser using indexed db

## Install
To install `@push.rocks/webstore`, use the following npm command:

```bash
npm install @push.rocks/webstore --save
```

This will add it to your project's dependencies.

## Usage
The `@push.rocks/webstore` module provides a high-performance storage solution for web applications, leveraging IndexedDB. This guide demonstrates how to use `@push.rocks/webstore` to store, retrieve, check, and manage data in the browser efficiently.

### Setting Up
Before using `@push.rocks/webstore`, you must import and instantiate a `WebStore` class. Specify a database name (`dbName`) and a store name (`storeName`) in the options:

```typescript
import { WebStore } from '@push.rocks/webstore';

const myStore = new WebStore<{
  [key: string]: any; // Define the shape of your store objects here
}>({
  dbName: 'myDatabase',
  storeName: 'myStore'
});
```

### Initializing the Store
To ensure the IndexedDB is set up correctly, call the `init` method before executing CRUD operations:

```typescript
await myStore.init();
```

### Storing Data
To store data, use the `set` method with a key and value. The value can be any object adhering to the store's object shape:

```typescript
await myStore.set('myKey', { some: 'data' });
```

### Retrieving Data
To retrieve data, use the `get` method with a key. This method returns a promise that resolves to the value associated with the key, or `undefined` if the key does not exist:

```typescript
const myData = await myStore.get('myKey');
console.log(myData); // { some: 'data' }
```

### Checking Data Existence
To check whether a key exists in the store, use the `check` method:

```typescript
const exists = await myStore.check('myKey');
console.log(exists); // true or false
```

### Deleting Data
To delete a specific entry, use the `delete` method with a key:

```typescript
await myStore.delete('myKey');
```

### Clearing the Store
To remove all entries from the store, use the `clear` method:

```typescript
await myStore.clear();
```

### Fetching All Keys
To retrieve all keys from the store, use the `keys` method. It returns a promise that resolves to an array of keys:

```typescript
const allKeys = await myStore.keys();
console.log(allKeys); // ['myKey', ...]
```

### Typed Request Caching
`@push.rocks/webstore` also includes a feature for caching typed requests using the `TypedrequestCache` class. This is particularly useful for caching API requests and their responses.

To set up a `TypedrequestCache`:

```typescript
import { TypedrequestCache } from '@push.rocks/webstore';

const myCache = new TypedrequestCache('domainIdentifier');
```

Store a request and its response:

```typescript
await myCache.setByRequest({
  method: 'GET',
  request: 'https://example.com/api/data',
  response: { data: 'response data' }
});
```

Retrieve a cached request by making a partial request:

```typescript
const cachedResponse = await myCache.getByRequest({
  method: 'GET',
  request: 'https://example.com/api/data'
});
console.log(cachedResponse); // { data: 'response data' }
```

`@push.rocks/webstore` provides a comprehensive API to leverage browser storage efficiently while maintaining high performance.

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
